@@ -9,6 +9,11 @@
     CLEAVE_BG_COLOR = NULL,
     CLEAVE_DURATION = .1,
     CLEAVE_CENTER_VERTICAL = TRUE,
-    CLEAVE_CENTER_HORIZONTAL = TRUE
+    CLEAVE_CENTER_HORIZONTAL = TRUE,
+    CHISEL_COLOR = "darkgrey",
+    CHISEL_BG_COLOR = NULL,
+    CHISEL_DURATION = .1,
+    CHISEL_CENTER_VERTICAL = TRUE,
+    CHISEL_CENTER_HORIZONTAL = TRUE
   )
 }
\ No newline at end of file
